Page 155 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 155

Home

    loans, guaranteed by U. S. taxpayers, have served to
    expand the operations of international cartels and to
    advance their march toward a New World Order.

    The major changes in the world throughout the 20th
    century have not occurred just because of an ideological
    conflict between Communism and Capitalism. Many of
    these changes have involved control of natural resources
    and markets by these cartels, many of whom are
    among the Fortune 500 businesses in America.

    As mentioned in chapter 10, ever since the
    1917 Revolution, American businessmen have

    operated government protected monopolies in the
    Soviet Union with any form of private enterprise
    forbidden to any would be Russian entrepreneurs.
    For example, Armand Hammer operated an asbestos
    mining and pencil manufacturing concession in the
    Soviet Union before and after WW II. While the Soviets

    were murdering millions of their own people, and turning
    the Soviet Union into a giant slave camp, Armand
    Hammer was making a profit. Hammer even worked
    out a grain deal so that he could ship grain to feed his
    mine workers. This was passed off as a humanitarian
    gesture to feed starving Russians.

    Besides his business enterprises, Armand Hammer
    represented thirty-eight other American companies in the
    Soviet Union. This information is related in Carl Blumy’s

    150

    The Secret Side of History

    to represent."’ Since the end of WW II these

    1917 Revolution,

    book The Dark Side of Power.

    Blumy was

    Armand